@@ -22,7 +22,8 @@
 
 #include <QList>
 
-namespace Wacom {
+namespace Wacom
+{
 
 /**
  * A typesafe enumeration template class. It can be used as a comfortable replacement
@@ -32,7 +33,7 @@ namespace Wacom {
  *   - enumerator lists are sorted by a given comparator
  *   - enumerators can have a key assigned
  *   - enumerator keys can be listed and searched for
- * 
+ *
  * NOTICE
  * This class uses template specialization to store a static set of all instances.
  * Thereofore a specialization of the private instances member  'instances' has
@@ -43,11 +44,11 @@ namespace Wacom {
  * \tparam L A "less than" functor which can compare objects of type D*.
  * \tparam E A "equal to" functor which can compare objects of type K.
  */
-template< class D, class K, class L, class E >
-class Enum {
-
+template<class D, class K, class L, class E>
+class Enum
+{
 private:
-    typedef QList<const D*>                    Container;
+    typedef QList<const D *> Container;
     typedef typename Container::const_iterator ContainerConstIterator;
 
 public:
@@ -58,77 +59,114 @@ public:
      */
     class const_iterator
     {
-        public:
-            const_iterator() {}
-            const_iterator(const const_iterator& iter) { operator=(iter); }
-            const_iterator(const ContainerConstIterator& iter) { m_iter = iter; }
+    public:
+        const_iterator()
+        {
+        }
+        const_iterator(const const_iterator &iter)
+        {
+            operator=(iter);
+        }
+        const_iterator(const ContainerConstIterator &iter)
+        {
+            m_iter = iter;
+        }
 
-            const D&         operator*() const { return **m_iter; }
-            const D*         operator->() const { return *m_iter; }
-            const_iterator&  operator= (const const_iterator& iter) { m_iter = iter.m_iter; return *this; }
-            bool             operator==(const const_iterator& iter) const { return (m_iter == iter.m_iter); }
-            bool             operator!=(const const_iterator& iter) const { return (m_iter != iter.m_iter); }
-            const_iterator&  operator++() { ++m_iter; return *this; }
-            const_iterator   operator++(int) { const_iterator copy(*this); ++(*this); return copy; }
-            const_iterator&  operator--() { --m_iter; return *this; }
-            const_iterator   operator--(int) { const_iterator copy(*this); --(*this); return copy; }
+        const D &operator*() const
+        {
+            return **m_iter;
+        }
+        const D *operator->() const
+        {
+            return *m_iter;
+        }
+        const_iterator &operator=(const const_iterator &iter)
+        {
+            m_iter = iter.m_iter;
+            return *this;
+        }
+        bool operator==(const const_iterator &iter) const
+        {
+            return (m_iter == iter.m_iter);
+        }
+        bool operator!=(const const_iterator &iter) const
+        {
+            return (m_iter != iter.m_iter);
+        }
+        const_iterator &operator++()
+        {
+            ++m_iter;
+            return *this;
+        }
+        const_iterator operator++(int)
+        {
+            const_iterator copy(*this);
+            ++(*this);
+            return copy;
+        }
+        const_iterator &operator--()
+        {
+            --m_iter;
+            return *this;
+        }
+        const_iterator operator--(int)
+        {
+            const_iterator copy(*this);
+            --(*this);
+            return copy;
+        }
 
-        private:
-            ContainerConstIterator m_iter;
+    private:
+        ContainerConstIterator m_iter;
     };
 
-    
     /**
      * Equal-Compare Operator.
      */
-    bool operator==(const Enum<D,K,L,E>& that) const
+    bool operator==(const Enum<D, K, L, E> &that) const
     {
         return (m_derived == that.m_derived);
     }
 
-    
     /**
      * Not-Equal-Compare Operator.
      */
-    bool operator!=(const Enum<D,K,L,E>& that) const
+    bool operator!=(const Enum<D, K, L, E> &that) const
     {
         return (m_derived != that.m_derived);
     }
 
-    
     /**
      * @return A constant iterator to the first element.
      */
     static const_iterator begin()
     {
         // force the use of const_iterator - fixes compile problem with some containers
-        const Enum<D,K,L,E>::Container* container = &Enum<D,K,L,E>::instances;
+        const Enum<D, K, L, E>::Container *container = &Enum<D, K, L, E>::instances;
         return const_iterator(container->begin());
     }
 
-
     /**
      * @return A constant iterator to the last element.
      */
     static const_iterator end()
     {
         // force the use of const_iterator - fixes compile problem with some containers
-        const Enum<D,K,L,E>::Container* container = &Enum<D,K,L,E>::instances;
+        const Enum<D, K, L, E>::Container *container = &Enum<D, K, L, E>::instances;
         return const_iterator(container->end());
     }
 
-
     /**
      * Searches for the enumeration instance by key.
      *
      * @param key The key of the instance to search.
-     * 
+     *
      * @return A constant pointer to the instance or nullptr if not found.
      */
-    static const D* find(const K& key)
+    static const D *find(const K &key)
     {
         E comp;
-        for (const_iterator i = begin() ; i != end() ; ++i) {
+        for (const_iterator i = begin(); i != end(); ++i) {
             if (comp(i->key(), key)) {
                 return &(*i);
             }
@@ -136,24 +174,22 @@ public:
         return nullptr;
     }
 
-
     /**
      * @return A list of all valid enum instances of this specialization.
      */
     static QList<D> list()
     {
         QList<D> enums;
-        for (const_iterator i = begin() ; i != end() ; ++i) {
+        for (const_iterator i = begin(); i != end(); ++i) {
             enums.push_back(*i);
         }
         return enums;
     }
 
-
     /**
      * @return The key of this enum instance.
      */
-    const K& key() const
+    const K &key() const
     {
         return m_key;
     }
@@ -166,25 +202,21 @@ public:
     static QList<K> keys()
     {
         QList<K> keys;
-        for (const_iterator i = begin() ; i != end() ; ++i) {
+        for (const_iterator i = begin(); i != end(); ++i) {
             keys.push_back(i->key());
         }
         return keys;
     }
 
-
     /**
      * @return The number of enum instances of this specialization.
      */
     static size_type size()
     {
-        return Enum<D,K,L,E>::instances.size();
+        return Enum<D, K, L, E>::instances.size();
     }
 
-
-    
 protected:
-
     /**
      * Initialization constructor.
      * Used to initialize class-static members. Never make this constructor
@@ -194,7 +226,8 @@ protected:
      * @param derived A const pointer to the derived class of this instance.
      * @param key The key of this class-static Enum instance.
      */
-    explicit Enum( const D* derived, const K& key ) : m_key(key)
+    explicit Enum(const D *derived, const K &key)
+        : m_key(key)
     {
         m_derived = derived;
         insert(derived);
@@ -203,27 +236,24 @@ protected:
     /**
      * \return A const pointer to the derived class of this instance.
      */
-    const D* derived() const
+    const D *derived() const
     {
         return m_derived;
     }
 
-
-    
 private:
-
     /**
      * Inserts an element into to the static instances container.
      * This method should only be called by the constructor!
      *
      * \param derived An instance of the derived class, never NULL.
      */
-    void insert(const D* derived)
+    void insert(const D *derived)
     {
         L comp;
-        typename Enum<D,K,L,E>::Container::iterator i = this->instances.begin();
+        typename Enum<D, K, L, E>::Container::iterator i = this->instances.begin();
 
-        for (; i != this->instances.end() ; ++i) {
+        for (; i != this->instances.end(); ++i) {
             if (comp(derived, *i)) {
                 this->instances.insert(i, derived);
                 return;
@@ -233,8 +263,8 @@ private:
         this->instances.push_back(derived);
     }
 
-    K        m_key;     /**< The key of this instance */
-    const D* m_derived; /**< Pointer to derived class for fast comparison */
+    K m_key; /**< The key of this instance */
+    const D *m_derived; /**< Pointer to derived class for fast comparison */
 
     /**
      * A static container with all the class-static Enum instances.
@@ -243,6 +273,6 @@ private:
      */
     static Container instances;
 
-};     // CLASS
-}      // NAMESPACE
+}; // CLASS
+} // NAMESPACE
 #endif // HEADER PROTECTION
